<?php
/**
 * Theme functions and definitions
 *
 * @package medical_insight
 */ 

if ( ! function_exists( 'medical_insight_enqueue_styles' ) ) :
	/**
	 * Load assets.
	 *
	 * @since 1.0.0
	 */
	function medical_insight_enqueue_styles() {
		wp_enqueue_style( 'medical-care-style-parent', get_template_directory_uri() . '/style.css' );
		wp_enqueue_style( 'medical-insight-style', get_stylesheet_directory_uri() . '/style.css', array( 'medical-care-style-parent' ), '1.0.0' );
	}
endif;
add_action( 'wp_enqueue_scripts', 'medical_insight_enqueue_styles', 99 );

function medical_insight_setup() {
	add_theme_support( 'align-wide' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'title-tag' );
	add_theme_support('custom-background',array(
		'default-color' => 'ffffff',
	));
	add_image_size( 'medical-insight-featured-image', 2000, 1200, true );
	add_image_size( 'medical-insight-thumbnail-avatar', 100, 100, true );

	$GLOBALS['content_width'] = 525;
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'medical-insight' ),
	) );

	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Add theme support for Custom Logo.
	add_theme_support( 'custom-logo', array(
		'width'       => 250,
		'height'      => 250,
		'flex-width'  => true,
	) );
}
add_action( 'after_setup_theme', 'medical_insight_setup' );

function medical_insight_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'medical-insight' ),
		'id'            => 'sidebar-1',
		'description'   => __( 'Add widgets here to appear in your sidebar on blog posts and archive pages.', 'medical-insight' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'medical-insight' ),
		'id'            => 'sidebar-2',
		'description'   => __( 'Add widgets here to appear in your pages and posts', 'medical-insight' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 1', 'medical-insight' ),
		'id'            => 'footer-1',
		'description'   => __( 'Add widgets here to appear in your footer.', 'medical-insight' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 2', 'medical-insight' ),
		'id'            => 'footer-2',
		'description'   => __( 'Add widgets here to appear in your footer.', 'medical-insight' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 3', 'medical-insight' ),
		'id'            => 'footer-3',
		'description'   => __( 'Add widgets here to appear in your footer.', 'medical-insight' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 4', 'medical-insight' ),
		'id'            => 'footer-4',
		'description'   => __( 'Add widgets here to appear in your footer.', 'medical-insight' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'medical_insight_widgets_init' );

function medical_insight_customize_register() {
  	global $wp_customize;
	$wp_customize->remove_section( 'medical_care_pro' );
	$wp_customize->remove_section( 'medical_care_header' );
}
add_action( 'customize_register', 'medical_insight_customize_register', 11 );

function medical_insight_remove_parent_function() {
    remove_action( 'admin_menu', 'medical_care_gettingstarted' );
}
add_action( 'wp_loaded', 'medical_insight_remove_parent_function' );

function medical_insight_customize( $wp_customize ) {

	// Social Media
    $wp_customize->add_section('medical_insight_urls',array(
        'title' => __('Social Media', 'medical-insight'),
        'description' => __( 'Add social media links in the below feilds', 'medical-insight' ),
        'priority' => 4,
    ) );
    
	$wp_customize->add_setting('medical_insight_facebook',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw'
	)); 
	$wp_customize->add_control('medical_insight_facebook',array(
		'label' => esc_html__('Facebook URL','medical-insight'),
		'section' => 'medical_insight_urls',
		'setting' => 'medical_insight_facebook',
		'type'    => 'url'
	));

	$wp_customize->add_setting('medical_insight_twitter',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw'
	)); 
	$wp_customize->add_control('medical_insight_twitter',array(
		'label' => esc_html__('Twitter URL','medical-insight'),
		'section' => 'medical_insight_urls',
		'setting' => 'medical_insight_twitter',
		'type'    => 'url'
	));

	$wp_customize->add_setting('medical_insight_youtube',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw'
	)); 
	$wp_customize->add_control('medical_insight_youtube',array(
		'label' => esc_html__('Youtube URL','medical-insight'),
		'section' => 'medical_insight_urls',
		'setting' => 'medical_insight_youtube',
		'type'    => 'url'
	));

	$wp_customize->add_setting('medical_insight_instagram',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw'
	)); 
	$wp_customize->add_control('medical_insight_instagram',array(
		'label' => esc_html__('Instagram URL','medical-insight'),
		'section' => 'medical_insight_urls',
		'setting' => 'medical_insight_instagram',
		'type'    => 'url'
	));

	// Top bar Links
    $wp_customize->add_section('medical_insight_topbar_links',array(
        'title' => __('Header Settings', 'medical-insight'),
        'description' => __( 'Add menu links in the below feilds', 'medical-insight' ),
        'priority' => 4,
    ) );

	$wp_customize->add_setting('medical_insight_text1',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	)); 
	$wp_customize->add_control('medical_insight_text1',array(
		'label' => esc_html__('Text 1','medical-insight'),
		'section' => 'medical_insight_topbar_links',
		'setting' => 'medical_insight_text1',
		'type'    => 'text'
	));
    
	$wp_customize->add_setting('medical_insight_link1',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw'
	)); 
	$wp_customize->add_control('medical_insight_link1',array(
		'label' => esc_html__('URL 1','medical-insight'),
		'section' => 'medical_insight_topbar_links',
		'setting' => 'medical_insight_link1',
		'type'    => 'url'
	));

	$wp_customize->add_setting('medical_insight_text2',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	)); 
	$wp_customize->add_control('medical_insight_text2',array(
		'label' => esc_html__('Text 2','medical-insight'),
		'section' => 'medical_insight_topbar_links',
		'setting' => 'medical_insight_text2',
		'type'    => 'text'
	));
    
	$wp_customize->add_setting('medical_insight_link2',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw'
	)); 
	$wp_customize->add_control('medical_insight_link2',array(
		'label' => esc_html__('URL 2','medical-insight'),
		'section' => 'medical_insight_topbar_links',
		'setting' => 'medical_insight_link2',
		'type'    => 'url'
	));

	$wp_customize->add_setting('medical_insight_text3',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	)); 
	$wp_customize->add_control('medical_insight_text3',array(
		'label' => esc_html__('Text 3','medical-insight'),
		'section' => 'medical_insight_topbar_links',
		'setting' => 'medical_insight_text3',
		'type'    => 'text'
	));
    
	$wp_customize->add_setting('medical_insight_link3',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw'
	)); 
	$wp_customize->add_control('medical_insight_link3',array(
		'label' => esc_html__('URL 3','medical-insight'),
		'section' => 'medical_insight_topbar_links',
		'setting' => 'medical_insight_link3',
		'type'    => 'url'
	));

	// About us
	$wp_customize->add_section( 'medical_insight_middle_section' , array(
    	'title'      => __( 'About us Settings', 'medical-insight' ),
		'priority'   => 6,
	) );

	$wp_customize->add_setting('medical_insight_about_title',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	)); 
	$wp_customize->add_control('medical_insight_about_title',array(
		'label' => esc_html__('Title','medical-insight'),
		'section' => 'medical_insight_middle_section',
		'setting' => 'medical_insight_about_title',
		'type'    => 'text'
	));
	
	$wp_customize->add_setting('medical_insight_middle_sec_page_settigs',array(
		'sanitize_callback' => 'medical_care_sanitize_dropdown_pages',
	));
	$wp_customize->add_control('medical_insight_middle_sec_page_settigs',array(
		'type'    => 'dropdown-pages',
		'label' => __('Select Page','medical-insight'),
		'section' => 'medical_insight_middle_section',
	));

	$args = array('numberposts' => -1); 
	$post_list = get_posts($args);
	$s = 0;	
	$pst_sls[]= __('Select','medical-insight');
	foreach ($post_list as $key => $p_post) {
		$pst_sls[$p_post->ID]=$p_post->post_title;
	}
	for ( $s = 1; $s <= 4; $s++ ) {
		$wp_customize->add_setting('medical_insight_mid_section_icon'.$s,array(
			'default' => '',
			'sanitize_callback' => 'sanitize_text_field'
		));
		$wp_customize->add_control('medical_insight_mid_section_icon'.$s,array(
			'label' => esc_html__('Icon','medical-insight'),
			'description' => esc_html__('Add the fontawesome class to add icon ex: fas fa-envelope','medical-insight'),
			'section' => 'medical_insight_middle_section',
			'setting' => 'medical_insight_mid_section_icon',
			'type'    => 'text'
		));

		$wp_customize->add_setting('medical_insight_middle_sec_settigs'.$s,array(
			'sanitize_callback' => 'medical_care_sanitize_choices',
		));
		$wp_customize->add_control('medical_insight_middle_sec_settigs'.$s,array(
			'type'    => 'select',
			'choices' => $pst_sls,
			'label' => __('Select post','medical-insight'),
			'section' => 'medical_insight_middle_section',
		));
	}
	wp_reset_postdata();

}
add_action( 'customize_register', 'medical_insight_customize' );